@@ -2,6 +2,7 @@
 #define SAMSUNG_H
 
 #include "pirkeysetmetadata.h"
+#include "pirackeyset.h"
 
 class QObject;
 
@@ -213,6 +214,40 @@ public:
     QObject *guiObject);
 };
 
+class SamsungAC2: public PIRACKeyset
+{
+public:
+  SamsungAC2(
+    unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
+
+  virtual void getTurboModePairs(
+    PIRStatePairs &turboModePairs) const;
+
+  virtual void getSwingPairs(
+    PIRStatePairs &swingPairs) const;
+
+  virtual void getTemperaturePairs(
+    PIRStatePairs &temperaturePairs) const;
+
+  virtual void getFanPairs(
+    PIRStatePairs &fanPairs) const;
+
+  virtual void getModePairs(
+    PIRStatePairs &modePairs) const;
+
+  virtual void getAirCleanPairs(
+    PIRStatePairs &aircleanPairs) const;
+
+  virtual void getPowerPairs(
+    PIRStatePairs &powerPairs) const;
+
+  virtual void getTimerOptionPairs(
+    PIRStatePairs &timerOptionPairs) const;
+};
+
 class SamsungDVBT1: public PIRKeysetMetaData
 {
 public:
