@@ -9,40 +9,50 @@ class Tivo1: public PIRKeysetMetaData
 {
 public:
   Tivo1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class Tivo1a: public Tivo1
 {
 public:
   Tivo1a(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class Tivo1b: public Tivo1
 {
 public:
   Tivo1b(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class Tivo1c: public Tivo1
 {
 public:
   Tivo1c(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class Tivo1d: public Tivo1
 {
 public:
   Tivo1d(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 #endif // TIVO_H
