@@ -5,10 +5,20 @@
 
 class QObject;
 
-class ZenithC32V37: public PIRKeysetMetaData
+class ZenithTV1: public PIRKeysetMetaData
 {
 public:
-  ZenithC32V37(
+  ZenithTV1(
+    unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
+};
+
+class ZenithConverterBox1: public PIRKeysetMetaData
+{
+public:
+  ZenithConverterBox1(
     unsigned int index);
 
   virtual void populateProtocol(
