@@ -38,6 +38,7 @@
 #include "keysets/dish.h"
 #include "keysets/dreambox.h"
 #include "keysets/dse.h"
+#include "keysets/dune.h"
 #include "keysets/dynex.h"
 #include "keysets/ei.h"
 #include "keysets/elgato.h"
@@ -82,6 +83,7 @@
 #include "keysets/medion.h"
 #include "keysets/mitsubishi.h"
 #include "keysets/motorola.h"
+#include "keysets/mtlogic.h"
 #include "keysets/multichoice.h"
 #include "keysets/nad.h"
 #include "keysets/nec.h"
@@ -127,6 +129,7 @@
 #include "keysets/triax.h"
 #include "keysets/united.h"
 #include "keysets/universum.h"
+#include "keysets/venturer.h"
 #include "keysets/vestel.h"
 #include "keysets/viewsat.h"
 #include "keysets/viewsonic.h"
@@ -239,7 +242,6 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new ComproTVCard1(++counter));
 
   setupKeyset(new CreativeAudio1(++counter));
-  setupKeyset(new CreativeAudioEx(++counter));
   setupKeyset(new CreativeAudio2(++counter));
   setupKeyset(new CreativeAudio3(++counter));
   setupKeyset(new CreativeAudio4(++counter));
@@ -322,6 +324,8 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new DSEDVD1(++counter));
   setupKeyset(new DSESat1(++counter));
 
+  setupKeyset(new DuneSTB1(++counter));
+
   setupKeyset(new DynexTV1(++counter));
 
   setupKeyset(new EiTV1(++counter));
@@ -335,7 +339,7 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new EmtecSTB2(++counter));
 
   setupKeyset(new EpsonProjector1(++counter));
-  setupKeyset(new EpsonProjector2(++counter));
+  setupKeyset(new EpsonProjector1a(++counter));
 
   setupKeyset(new FortecReceiver1(++counter));
   setupKeyset(new FortecReceiver2(++counter));
@@ -536,6 +540,8 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new MotorolaSTB1b(++counter));
   setupKeyset(new MotorolaSkyDigital(++counter));
 
+  setupKeyset(new MTLogicTV1(++counter));
+
   setupKeyset(new MultichoiceSTB1(++counter));
   setupKeyset(new MultichoiceSTB2(++counter));
 
@@ -851,6 +857,10 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new UniversumSat1(++counter));
   setupKeyset(new UniversumAudio1(++counter));
 
+  setupKeyset(new VenturerTV1(++counter));
+  setupKeyset(new VenturerDVD1(++counter));
+  setupKeyset(new VenturerSTB1(++counter));
+
   setupKeyset(new VestelTV1(++counter));
   setupKeyset(new VestelTV2(++counter));
 
