@@ -12,6 +12,8 @@
 #include "forms/pirinputform.h"
 #include "forms/piradjustform.h"
 #include "forms/pirairconditionerform.h"
+#include "forms/pirstatefulacform.h"
+#include "forms/piractimerform.h"
 #include "forms/piraudiodeviceform.h"
 #include "forms/pircameraform.h"
 #include "forms/pirroombaform.h"
@@ -44,6 +46,8 @@ PIRPanelManager::PIRPanelManager(
     inputForm(0),
     adjustForm(0),
     acForm(0),
+    statefulACForm(0),
+    acTimerForm(0),
     audioDeviceForm(0),
     cameraForm(0),
     roombaForm(0),
@@ -101,9 +105,15 @@ PIRPanelManager::PIRPanelManager(
   shortPanelNames[Adjust_Panel] = "Adjust";
   longPanelNames[Adjust_Panel] =
     "Adjust Panel - modify audio and video";
-  shortPanelNames[AC_Panel] = "AC";
+  shortPanelNames[AC_Panel] = "Stateless AC";
   longPanelNames[AC_Panel] =
     "A/C Panel - air conditioner controls";
+  shortPanelNames[StatefulAC_Panel] = "Stateful AC";
+  longPanelNames[StatefulAC_Panel] =
+    "Stateful A/C Panel - for A/C remotes with LCD screens";
+  shortPanelNames[ACTimer_Panel] = "Timer";
+  longPanelNames[ACTimer_Panel] =
+    "A/C Timer Panel - set (or cancel) the on/off timer";
   shortPanelNames[Audio_Panel] = "Audio";
   longPanelNames[Audio_Panel] =
     "Audio Device Panel - various audio related buttons";
@@ -162,6 +172,12 @@ PIRPanelManager::PIRPanelManager(
   acForm = new PIRAirConditionerForm(mainWindow);
   panels[AC_Panel] = acForm;
 
+  statefulACForm = new PIRStatefulACForm(mainWindow);
+  panels[StatefulAC_Panel] = statefulACForm;
+
+  acTimerForm = new PIRACTimerForm(mainWindow);
+  panels[ACTimer_Panel] = acTimerForm;
+
   audioDeviceForm = new PIRAudioDeviceForm(mainWindow);
   panels[Audio_Panel] = audioDeviceForm;
 
@@ -227,6 +243,8 @@ PIRPanelManager::PIRPanelManager(
   // The air conditioner collection:
   pset.clear();
   pset.push_back(AC_Panel);
+  pset.push_back(StatefulAC_Panel);
+  pset.push_back(ACTimer_Panel);
   tabLists[AC_Tabs] = pset;
 
   // The recording collection:
@@ -335,6 +353,8 @@ void PIRPanelManager::commonEnableButtons(
   inputForm->enableButtons(keyset, id);
   adjustForm->enableButtons(keyset, id);
   acForm->enableButtons(keyset, id);
+  statefulACForm->enableButtons(keyset, id);
+  acTimerForm->enableButtons(keyset, id);
   audioDeviceForm->enableButtons(keyset, id);
   cameraForm->enableButtons(keyset, id);
   roombaForm->enableButtons(keyset, id);
