@@ -15,10 +15,14 @@ class PIRTVForm;
 class PIRInputForm;
 class PIRAdjustForm;
 class PIRAirConditionerForm;
+class PIRStatefulACForm;
+class PIRACTimerForm;
 class PIRAudioDeviceForm;
 class PIRCameraForm;
 class PIRRoombaForm;
 class PIRUserForm;
+
+// These need to go elsewhere:
 class PIRMacroForm;
 //class PIRPowerSearchForm;
 class PIRAdvancedForm;
@@ -96,6 +100,8 @@ private:
   PIRInputForm *inputForm;
   PIRAdjustForm *adjustForm;
   PIRAirConditionerForm *acForm;
+  PIRStatefulACForm *statefulACForm;
+  PIRACTimerForm *acTimerForm;
   PIRAudioDeviceForm *audioDeviceForm;
   PIRCameraForm *cameraForm;
   PIRRoombaForm *roombaForm;
