@@ -31,4 +31,4 @@ private:
     PIRRX51Hardware &device);
 };
 
-#endif // NECPROTOCOL_H
+#endif // THOMSONPROTOCOL_H
